package com.sun.java.swing.plaf.motif;

import java.awt.Point;
import javax.swing.MenuSelectionManager;
import java.awt.event.MouseEvent;
import javax.swing.LookAndFeel;
import javax.swing.JMenuItem;
import javax.swing.event.ChangeEvent;
import javax.swing.event.MouseInputListener;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.event.ChangeListener;
import javax.swing.plaf.basic.BasicMenuItemUI;

public class MotifMenuItemUI extends BasicMenuItemUI
{
    protected ChangeListener changeListener;
    
    public MotifMenuItemUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new MotifMenuItemUI();
    }
    
    @Override
    protected void installListeners() {
        super.installListeners();
        this.changeListener = this.createChangeListener(this.menuItem);
        this.menuItem.addChangeListener(this.changeListener);
    }
    
    @Override
    protected void uninstallListeners() {
        super.uninstallListeners();
        this.menuItem.removeChangeListener(this.changeListener);
    }
    
    protected ChangeListener createChangeListener(JComponent component) {
        return new MotifMenuItemUI.ChangeHandler();
    }
    
    @Override
    protected MouseInputListener createMouseInputListener(JComponent component) {
        return new MotifMenuItemUI.MouseInputHandler();
    }
    
    protected class ChangeHandler implements ChangeListener
    {
        @Override
        public void stateChanged(ChangeEvent changeEvent) {
            JMenuItem c = (JMenuItem)changeEvent.getSource();
            LookAndFeel.installProperty(c, "borderPainted", Boolean.valueOf(c.isArmed() || c.isSelected()));
        }
    }
    
    protected class MouseInputHandler implements MouseInputListener
    {
        @Override
        public void mouseClicked(MouseEvent mouseEvent) {
        }
        
        @Override
        public void mousePressed(MouseEvent mouseEvent) {
            MenuSelectionManager.defaultManager().setSelectedPath(MotifMenuItemUI.this.getPath());
        }
        
        @Override
        public void mouseReleased(MouseEvent event) {
            MenuSelectionManager defaultManager = MenuSelectionManager.defaultManager();
            JMenuItem menuItem = (JMenuItem)event.getComponent();
            Point point = event.getPoint();
            if (point.x >= 0 && point.x < menuItem.getWidth() && point.y >= 0 && point.y < menuItem.getHeight()) {
                defaultManager.clearSelectedPath();
                menuItem.doClick(0);
            }
            else {
                defaultManager.processMouseEvent(event);
            }
        }
        
        @Override
        public void mouseEntered(MouseEvent mouseEvent) {
        }
        
        @Override
        public void mouseExited(MouseEvent mouseEvent) {
        }
        
        @Override
        public void mouseDragged(MouseEvent event) {
            MenuSelectionManager.defaultManager().processMouseEvent(event);
        }
        
        @Override
        public void mouseMoved(MouseEvent mouseEvent) {
        }
    }
}
